meeg\_utils.preprocessing.bad\_channels
=======================================

.. automodule:: meeg_utils.preprocessing.bad_channels


   .. rubric:: Functions

   .. autosummary::

      detect_bad_channels_eeg
      detect_bad_channels_meg
